@@ -1,5 +1,6 @@
 from abc import ABC
-from typing import Any, List, Optional
+from functools import lru_cache
+from typing import Any, List
 
 from easydata.data import DataBag
 from easydata.managers import ModelManager
@@ -12,9 +13,7 @@ class BaseModel(ABC):
 
     data_processors: List[DataBaseProcessor] = []
 
-    items_processors: List[BaseProcessor] = []
-
-    _model_manager: Optional[ModelManager] = None
+    item_processors: List[BaseProcessor] = []
 
     def preprocess_data(self, data: DataBag):
         return data
@@ -28,12 +27,16 @@ class BaseModel(ABC):
     def process_item(self, item: dict):
         return item
 
-    @property
-    def model_manager(self):
-        if not self._model_manager:
-            self._model_manager = ModelManager(self)
+    def init_model(self):
+        pass
 
-        return self._model_manager
+    def initialized_model(self):
+        pass
+
+    @property  # type: ignore
+    @lru_cache(maxsize=None)
+    def model_manager(self) -> ModelManager:
+        return ModelManager(self)
 
     def _parse_items(
         self,
